@@ -96,6 +96,7 @@ find_statistic <- function(x, ...) {
       "coxph",
       "crch",
       "ergm",
+      "fixest",
       "flexsurvreg",
       "gee",
       "glimML",
@@ -105,6 +106,7 @@ find_statistic <- function(x, ...) {
       "gmnl",
       "hurdle",
       "lavaan",
+      "loggammacenslmrob",
       "LORgee",
       "lrm",
       "MixMod",
@@ -114,9 +116,12 @@ find_statistic <- function(x, ...) {
       "mclogit",
       "mmclogit",
       "negbin",
+      "nlreg",
+      "objectiveML",
       "psm",
       "rma",
       "rma.uni",
+      "sem",
       "slm",
       "survreg",
       "tobit",
