@@ -64,6 +64,7 @@ is_model <- function(x) {
       "feis",
       "felm",
       "fitdistr",
+      "fixest",
       "flexsurvreg",
       "gam",
       "Gam",
@@ -108,6 +109,7 @@ is_model <- function(x) {
       "lme",
       "lmrob",
       "lmRob",
+      "loggammacenslmrob",
       "logistf",
       "loo",
       "LORgee",
@@ -131,8 +133,10 @@ is_model <- function(x) {
       "multinom",
       "mvr",
       "negbin",
+      "nlreg",
       "nlrq",
       "nls",
+      "objectiveML",
       "ols",
       "orcutt",
       "plm",
@@ -150,6 +154,7 @@ is_model <- function(x) {
       "rms",
       "rq",
       "rqss",
+      "sem",
       "slm",
       "speedlm",
       "speedglm",
