@@ -58,12 +58,14 @@ supported_models <- function() {
     "clm2",
     "clmm",
     "clmm2",
+    "complmrob",
     "coxme",
     "coxph",
     "crch",
     "crq",
     "feis",
     "felm",
+    "fixest",
     "flexsurvreg",
     "gam",
     "Gam",
@@ -100,7 +102,9 @@ supported_models <- function() {
     "mixed",
     "MixMod",
     "mlm",
+    "mclogit",
     "mlogit",
+    "mmlogit",
     "multinom",
     "plm",
     "polr",
