@@ -236,6 +236,20 @@ n_obs.feis <- function(x, ...) {
 
 
 
+#' @export
+n_obs.fixest <- function(x, ...) {
+  x$nobs
+}
+
+
+
+#' @export
+n_obs.complmrob <- function(x, ...) {
+  nrow(get_data(x))
+}
+
+
+
 #' @export
 n_obs.aovlist <- function(x, ...) {
   nrow(stats::model.frame(x))
